#!/bin/bash

# Any failed command will terminate script
set -e

UPGRADE_KERNEL_VERSION="3.14.27"

# Ensure we're running an upgradable kernel, and the SBC3
_kversion="$( cat /proc/version | awk '{print $3}' )"
_board_name="$([ -e /proc/device-tree/model ] && (cat /proc/device-tree/model; echo '';) || (cat /proc/cpuinfo | awk '/^Hardware/ {print $3}'))"

if [ "$_kversion" != "$UPGRADE_KERNEL_VERSION" ]; then
	echo "This update package is not compatible with your kernel version: $_kversion"
	exit 1
fi

if [ "$_board_name" != "PhidgetSBC3" ]; then
	echo "This update package is not compatible with your board: $_board_name"
	exit 1
fi

read -p "Are you sure you want to update the kernel? (y/n)" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
	echo "Updating live kernel..."
	flash_eraseall /dev/mtd6
	nandwrite -p /dev/mtd6 uImage

	echo "Installing modules..."
	mv modules.tar.gz /lib/modules/
	(cd /lib/modules/; tar -zxf modules.tar.gz; rm modules.tar.gz; depmod)

	echo "Update completed successfully"
else
	echo "Update cancelled"
	echo
fi
